---
title: <span class="badge object-type-scalar"></span> MilliHenry
---
# <span class="badge object-type-scalar"></span> MilliHenry

Energy: Millihenry (mH)

## Definition

```python
# Energy: Millihenry (mH)
MilliHenry: typing.Literal["mhenry"] = "mhenry"
```
